@@ -203,6 +203,8 @@ class NetctlInterface(object):
         self.current_route = {}
         self.mac = ""
         self.changed = {}
+        self._lastError = None
+        self._lastCommand = None
         if cfgfile != None:
             self._parseFile(cfgfile)
             self.name = os.path.basename(cfgfile)
@@ -317,7 +319,7 @@ class NetctlInterface(object):
         cmd = 'netctl %s %s' % (command, self.name)
         out = run(cmd)
         self._lastError = out
-        self._lassCommand = cmd
+        self._lastCommand = cmd
         return out.rc == 0
 
     def restart(self):
