@@ -625,7 +625,7 @@ class UsersAndGroup(object):
             ldif.append('add: gidNumber')
             ldif.append('gidNumber: %s' % self.getNextGid())
             ldif.append('-')
-            ldif.append('add: msSFU30Name')
+            ldif.append('replace: msSFU30Name')
             ldif.append('msSFU30Name: %s' % name)
             ldif.append('-')
             ldif.append('add: msSFU30NisDomain')
@@ -639,7 +639,7 @@ class UsersAndGroup(object):
         if len(ldif) > 2:
             ret = modifyLdap(self._ldbSamFile, ldif)
             if type(ret) == dict:
-                raise SAMBAUserException('can not modify group ldap. STDOUT: % STDERR: %s' % (ret['stdout'], ret['stderr']))
+                raise SAMBAUserException('can not modify group ldap. STDOUT: %s STDERR: %s LDIFF: %s' % (ret['stdout'], ret['stderr'], ret['ldif']))
         return self.getGroupByAccount(name)
 
 def getAllInstalledShells():
