@@ -4,6 +4,8 @@ __author__ = 'Stephan Conrad <stephan@conrad.pics>'
 from exon.utils.share.NfsShare import NfsShareService, NfsShare
 from exon.utils.share.AfpShare import AfpShareService, AfpShare, AfpAcl
 from exon.utils.share.SmbShare import SmbShare, SmbShareService
+import os
+
 class ShareManager(object):
     """
     Class for managing Shares
@@ -40,15 +42,23 @@ class ShareManager(object):
 
     def writeShare(self, share):
         status = True
+        name = None
         for key in share:
+            name = share[key].name
             if key in self.services:
                 ret = self.services[key].writeShare(share[key])
                 if not ret:
                     status = ret
+        self.listShares()
+        tmp = self.getShare(name)
+        for key in share:
+            if key not in tmp:
+                status = False
         return status
 
     def fromJson(self, map):
         share = {}
+        shareTypes = {}
         for name in map:
             path = ''
             if name not in share:
@@ -61,11 +71,29 @@ class ShareManager(object):
                     share[name][key] = self.services[key].fromJson(map[name][key])
                     share[name][key].name = name
                     share[name][key].path = path
+        status = []
+        if not os.path.exists(path):
+            os.makedirs(path)
+        for name in share:
+            shareTypes[name] = []
+            ret = self.writeShare(share[name])
+            for key in share[name]:
+                shareTypes[name].append(key)
+                status.append('%s => %s' %(key, ret))
+        shares = self.listShares()
         status = True
         for name in share:
-            ret = self.writeShare(share[name])
-            if not ret:
-                status = ret
+            for key in shareTypes[name]:
+                if key not in shares[name]:
+                    self.writeShare(share[name])
+        shares = self.listShares()
+        for name in share:
+            if name in shares:
+                for key in share[name]:
+                    if key not in shares[name]:
+                        status = False
+            else:
+                status = False
         return status
 
     def delete(self, name):
